:mod:`euphorie.client.browser.session`
======================================

.. automodule:: euphorie.client.browser.session
   :members:

.. autoclass:: Profile
   :members:

.. autoclass:: Start

.. autoclass:: Update

.. autoclass:: Identification

.. autoclass:: ActionPlan

.. autoclass:: Status
   :members:

